import 'package:yumi/shared/business_logic/models/res/bags_list_res.dart';
import 'package:yumi/shared/business_logic/models/res/sc_room_theme_list_res.dart';
import 'package:yumi/shared/business_logic/models/res/store_list_res.dart';

abstract class SocialChatStoreRepository {
  ///获取商店道具
  Future<List<StoreListRes>> storeList(String SCCurrencyType, String SCPropsType);

  ///道具商店购买
  Future<double> storePurchasing(
    String propsId,
    String type,
    String SCCurrencyType,
    String days, {
    String? acceptUserId,
  });

  ///用户道具背包
  Future<List<BagsListRes>> storeBackpack(String userId, String type);

  ///佩戴道具
  Future<bool> switchPropsUse(String type, String propsId, bool unload);

  ///切换主题
  Future<bool> themeSwitchUse(String themeId, bool unload);

  ///获取最新的自定义主题
  Future<SCRoomThemeListRes> themeCustomizeLatest();

  ///我的主题背包
  Future<List<SCRoomThemeListRes>> roomThemeBackpack();

  ///上传自定义主题
  Future<double> roomThemeCustomize(String themeUrl);
}
